# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DSRecordsDsRecordArgs',
    'DSRecordsDsRecordArgsDict',
    'NameCurrentStateArgs',
    'NameCurrentStateArgsDict',
    'NameCurrentStateDnsConfigurationArgs',
    'NameCurrentStateDnsConfigurationArgsDict',
    'NameCurrentStateDnsConfigurationNameServerArgs',
    'NameCurrentStateDnsConfigurationNameServerArgsDict',
    'NameCurrentTaskArgs',
    'NameCurrentTaskArgsDict',
    'NameIamArgs',
    'NameIamArgsDict',
    'NameOrderArgs',
    'NameOrderArgsDict',
    'NameOrderDetailArgs',
    'NameOrderDetailArgsDict',
    'NamePlanArgs',
    'NamePlanArgsDict',
    'NamePlanConfigurationArgs',
    'NamePlanConfigurationArgsDict',
    'NamePlanOptionArgs',
    'NamePlanOptionArgsDict',
    'NamePlanOptionConfigurationArgs',
    'NamePlanOptionConfigurationArgsDict',
    'NameServersServerArgs',
    'NameServersServerArgsDict',
    'NameTargetSpecArgs',
    'NameTargetSpecArgsDict',
    'NameTargetSpecDnsConfigurationArgs',
    'NameTargetSpecDnsConfigurationArgsDict',
    'NameTargetSpecDnsConfigurationNameServerArgs',
    'NameTargetSpecDnsConfigurationNameServerArgsDict',
    'ZoneOrderArgs',
    'ZoneOrderArgsDict',
    'ZoneOrderDetailArgs',
    'ZoneOrderDetailArgsDict',
    'ZonePlanArgs',
    'ZonePlanArgsDict',
    'ZonePlanConfigurationArgs',
    'ZonePlanConfigurationArgsDict',
    'ZonePlanOptionArgs',
    'ZonePlanOptionArgsDict',
    'ZonePlanOptionConfigurationArgs',
    'ZonePlanOptionConfigurationArgsDict',
]

MYPY = False

if not MYPY:
    class DSRecordsDsRecordArgsDict(TypedDict):
        algorithm: pulumi.Input[builtins.str]
        """
        The record algorithm (`RSASHA1`, `RSASHA1_NSEC3_SHA1`, `RSASHA256`, `RSASHA512`, `ECDSAP256SHA256`, `ECDSAP384SHA384`, `ED25519`)
        """
        flags: pulumi.Input[builtins.str]
        """
        The record flag (`ZONE_SIGNING_KEY`, `KEY_SIGNING_KEY`)
        """
        public_key: pulumi.Input[builtins.str]
        """
        The record base64 encoded public key
        """
        tag: pulumi.Input[builtins.int]
        """
        The record tag
        """
elif False:
    DSRecordsDsRecordArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DSRecordsDsRecordArgs:
    def __init__(__self__, *,
                 algorithm: pulumi.Input[builtins.str],
                 flags: pulumi.Input[builtins.str],
                 public_key: pulumi.Input[builtins.str],
                 tag: pulumi.Input[builtins.int]):
        """
        :param pulumi.Input[builtins.str] algorithm: The record algorithm (`RSASHA1`, `RSASHA1_NSEC3_SHA1`, `RSASHA256`, `RSASHA512`, `ECDSAP256SHA256`, `ECDSAP384SHA384`, `ED25519`)
        :param pulumi.Input[builtins.str] flags: The record flag (`ZONE_SIGNING_KEY`, `KEY_SIGNING_KEY`)
        :param pulumi.Input[builtins.str] public_key: The record base64 encoded public key
        :param pulumi.Input[builtins.int] tag: The record tag
        """
        pulumi.set(__self__, "algorithm", algorithm)
        pulumi.set(__self__, "flags", flags)
        pulumi.set(__self__, "public_key", public_key)
        pulumi.set(__self__, "tag", tag)

    @property
    @pulumi.getter
    def algorithm(self) -> pulumi.Input[builtins.str]:
        """
        The record algorithm (`RSASHA1`, `RSASHA1_NSEC3_SHA1`, `RSASHA256`, `RSASHA512`, `ECDSAP256SHA256`, `ECDSAP384SHA384`, `ED25519`)
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "algorithm", value)

    @property
    @pulumi.getter
    def flags(self) -> pulumi.Input[builtins.str]:
        """
        The record flag (`ZONE_SIGNING_KEY`, `KEY_SIGNING_KEY`)
        """
        return pulumi.get(self, "flags")

    @flags.setter
    def flags(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "flags", value)

    @property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> pulumi.Input[builtins.str]:
        """
        The record base64 encoded public key
        """
        return pulumi.get(self, "public_key")

    @public_key.setter
    def public_key(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "public_key", value)

    @property
    @pulumi.getter
    def tag(self) -> pulumi.Input[builtins.int]:
        """
        The record tag
        """
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "tag", value)


if not MYPY:
    class NameCurrentStateArgsDict(TypedDict):
        additional_states: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        Domain additional states
        """
        dns_configuration: NotRequired[pulumi.Input['NameCurrentStateDnsConfigurationArgsDict']]
        """
        The domain DNS configuration
        """
        extension: NotRequired[pulumi.Input[builtins.str]]
        """
        Extension of the domain name
        """
        main_state: NotRequired[pulumi.Input[builtins.str]]
        """
        Domain main state
        """
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        Domain name
        """
        protection_state: NotRequired[pulumi.Input[builtins.str]]
        """
        Domain protection state
        """
        suspension_state: NotRequired[pulumi.Input[builtins.str]]
        """
        Domain suspension state
        """
elif False:
    NameCurrentStateArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameCurrentStateArgs:
    def __init__(__self__, *,
                 additional_states: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 dns_configuration: Optional[pulumi.Input['NameCurrentStateDnsConfigurationArgs']] = None,
                 extension: Optional[pulumi.Input[builtins.str]] = None,
                 main_state: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 protection_state: Optional[pulumi.Input[builtins.str]] = None,
                 suspension_state: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] additional_states: Domain additional states
        :param pulumi.Input['NameCurrentStateDnsConfigurationArgs'] dns_configuration: The domain DNS configuration
        :param pulumi.Input[builtins.str] extension: Extension of the domain name
        :param pulumi.Input[builtins.str] main_state: Domain main state
        :param pulumi.Input[builtins.str] name: Domain name
        :param pulumi.Input[builtins.str] protection_state: Domain protection state
        :param pulumi.Input[builtins.str] suspension_state: Domain suspension state
        """
        if additional_states is not None:
            pulumi.set(__self__, "additional_states", additional_states)
        if dns_configuration is not None:
            pulumi.set(__self__, "dns_configuration", dns_configuration)
        if extension is not None:
            pulumi.set(__self__, "extension", extension)
        if main_state is not None:
            pulumi.set(__self__, "main_state", main_state)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protection_state is not None:
            pulumi.set(__self__, "protection_state", protection_state)
        if suspension_state is not None:
            pulumi.set(__self__, "suspension_state", suspension_state)

    @property
    @pulumi.getter(name="additionalStates")
    def additional_states(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Domain additional states
        """
        return pulumi.get(self, "additional_states")

    @additional_states.setter
    def additional_states(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "additional_states", value)

    @property
    @pulumi.getter(name="dnsConfiguration")
    def dns_configuration(self) -> Optional[pulumi.Input['NameCurrentStateDnsConfigurationArgs']]:
        """
        The domain DNS configuration
        """
        return pulumi.get(self, "dns_configuration")

    @dns_configuration.setter
    def dns_configuration(self, value: Optional[pulumi.Input['NameCurrentStateDnsConfigurationArgs']]):
        pulumi.set(self, "dns_configuration", value)

    @property
    @pulumi.getter
    def extension(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Extension of the domain name
        """
        return pulumi.get(self, "extension")

    @extension.setter
    def extension(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "extension", value)

    @property
    @pulumi.getter(name="mainState")
    def main_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Domain main state
        """
        return pulumi.get(self, "main_state")

    @main_state.setter
    def main_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "main_state", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Domain name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="protectionState")
    def protection_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Domain protection state
        """
        return pulumi.get(self, "protection_state")

    @protection_state.setter
    def protection_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protection_state", value)

    @property
    @pulumi.getter(name="suspensionState")
    def suspension_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Domain suspension state
        """
        return pulumi.get(self, "suspension_state")

    @suspension_state.setter
    def suspension_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "suspension_state", value)


if not MYPY:
    class NameCurrentStateDnsConfigurationArgsDict(TypedDict):
        configuration_type: NotRequired[pulumi.Input[builtins.str]]
        """
        The type of DNS configuration of the domain
        """
        glue_record_ipv6supported: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether the registry supports IPv6 or not
        """
        host_supported: NotRequired[pulumi.Input[builtins.bool]]
        """
        Whether the registry accepts hosts or not
        """
        max_dns: NotRequired[pulumi.Input[builtins.float]]
        """
        The maximum number of name servers allowed by the registry
        """
        min_dns: NotRequired[pulumi.Input[builtins.float]]
        """
        The minimum number of name servers allowed by the registry
        """
        name_servers: NotRequired[pulumi.Input[Sequence[pulumi.Input['NameCurrentStateDnsConfigurationNameServerArgsDict']]]]
        """
        The name servers used by the domain name
        """
elif False:
    NameCurrentStateDnsConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameCurrentStateDnsConfigurationArgs:
    def __init__(__self__, *,
                 configuration_type: Optional[pulumi.Input[builtins.str]] = None,
                 glue_record_ipv6supported: Optional[pulumi.Input[builtins.bool]] = None,
                 host_supported: Optional[pulumi.Input[builtins.bool]] = None,
                 max_dns: Optional[pulumi.Input[builtins.float]] = None,
                 min_dns: Optional[pulumi.Input[builtins.float]] = None,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input['NameCurrentStateDnsConfigurationNameServerArgs']]]] = None):
        """
        :param pulumi.Input[builtins.str] configuration_type: The type of DNS configuration of the domain
        :param pulumi.Input[builtins.bool] glue_record_ipv6supported: Whether the registry supports IPv6 or not
        :param pulumi.Input[builtins.bool] host_supported: Whether the registry accepts hosts or not
        :param pulumi.Input[builtins.float] max_dns: The maximum number of name servers allowed by the registry
        :param pulumi.Input[builtins.float] min_dns: The minimum number of name servers allowed by the registry
        :param pulumi.Input[Sequence[pulumi.Input['NameCurrentStateDnsConfigurationNameServerArgs']]] name_servers: The name servers used by the domain name
        """
        if configuration_type is not None:
            pulumi.set(__self__, "configuration_type", configuration_type)
        if glue_record_ipv6supported is not None:
            pulumi.set(__self__, "glue_record_ipv6supported", glue_record_ipv6supported)
        if host_supported is not None:
            pulumi.set(__self__, "host_supported", host_supported)
        if max_dns is not None:
            pulumi.set(__self__, "max_dns", max_dns)
        if min_dns is not None:
            pulumi.set(__self__, "min_dns", min_dns)
        if name_servers is not None:
            pulumi.set(__self__, "name_servers", name_servers)

    @property
    @pulumi.getter(name="configurationType")
    def configuration_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of DNS configuration of the domain
        """
        return pulumi.get(self, "configuration_type")

    @configuration_type.setter
    def configuration_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "configuration_type", value)

    @property
    @pulumi.getter(name="glueRecordIpv6supported")
    def glue_record_ipv6supported(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the registry supports IPv6 or not
        """
        return pulumi.get(self, "glue_record_ipv6supported")

    @glue_record_ipv6supported.setter
    def glue_record_ipv6supported(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "glue_record_ipv6supported", value)

    @property
    @pulumi.getter(name="hostSupported")
    def host_supported(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether the registry accepts hosts or not
        """
        return pulumi.get(self, "host_supported")

    @host_supported.setter
    def host_supported(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "host_supported", value)

    @property
    @pulumi.getter(name="maxDns")
    def max_dns(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        The maximum number of name servers allowed by the registry
        """
        return pulumi.get(self, "max_dns")

    @max_dns.setter
    def max_dns(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "max_dns", value)

    @property
    @pulumi.getter(name="minDns")
    def min_dns(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        The minimum number of name servers allowed by the registry
        """
        return pulumi.get(self, "min_dns")

    @min_dns.setter
    def min_dns(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "min_dns", value)

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NameCurrentStateDnsConfigurationNameServerArgs']]]]:
        """
        The name servers used by the domain name
        """
        return pulumi.get(self, "name_servers")

    @name_servers.setter
    def name_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NameCurrentStateDnsConfigurationNameServerArgs']]]]):
        pulumi.set(self, "name_servers", value)


if not MYPY:
    class NameCurrentStateDnsConfigurationNameServerArgsDict(TypedDict):
        ipv4: NotRequired[pulumi.Input[builtins.str]]
        """
        The IPv4 associated to the name server
        """
        ipv6: NotRequired[pulumi.Input[builtins.str]]
        """
        The IPv6 associated to the name server
        """
        name_server: NotRequired[pulumi.Input[builtins.str]]
        """
        The host name
        """
        name_server_type: NotRequired[pulumi.Input[builtins.str]]
        """
        The type of name server
        """
elif False:
    NameCurrentStateDnsConfigurationNameServerArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameCurrentStateDnsConfigurationNameServerArgs:
    def __init__(__self__, *,
                 ipv4: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6: Optional[pulumi.Input[builtins.str]] = None,
                 name_server: Optional[pulumi.Input[builtins.str]] = None,
                 name_server_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] ipv4: The IPv4 associated to the name server
        :param pulumi.Input[builtins.str] ipv6: The IPv6 associated to the name server
        :param pulumi.Input[builtins.str] name_server: The host name
        :param pulumi.Input[builtins.str] name_server_type: The type of name server
        """
        if ipv4 is not None:
            pulumi.set(__self__, "ipv4", ipv4)
        if ipv6 is not None:
            pulumi.set(__self__, "ipv6", ipv6)
        if name_server is not None:
            pulumi.set(__self__, "name_server", name_server)
        if name_server_type is not None:
            pulumi.set(__self__, "name_server_type", name_server_type)

    @property
    @pulumi.getter
    def ipv4(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IPv4 associated to the name server
        """
        return pulumi.get(self, "ipv4")

    @ipv4.setter
    def ipv4(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv4", value)

    @property
    @pulumi.getter
    def ipv6(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IPv6 associated to the name server
        """
        return pulumi.get(self, "ipv6")

    @ipv6.setter
    def ipv6(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6", value)

    @property
    @pulumi.getter(name="nameServer")
    def name_server(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The host name
        """
        return pulumi.get(self, "name_server")

    @name_server.setter
    def name_server(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name_server", value)

    @property
    @pulumi.getter(name="nameServerType")
    def name_server_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of name server
        """
        return pulumi.get(self, "name_server_type")

    @name_server_type.setter
    def name_server_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name_server_type", value)


if not MYPY:
    class NameCurrentTaskArgsDict(TypedDict):
        id: NotRequired[pulumi.Input[builtins.str]]
        """
        Identifier of the current task
        """
        link: NotRequired[pulumi.Input[builtins.str]]
        """
        Link to the task details
        """
        status: NotRequired[pulumi.Input[builtins.str]]
        """
        Current global status of the current task
        """
        type: NotRequired[pulumi.Input[builtins.str]]
        """
        Type of the current task
        """
elif False:
    NameCurrentTaskArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameCurrentTaskArgs:
    def __init__(__self__, *,
                 id: Optional[pulumi.Input[builtins.str]] = None,
                 link: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] id: Identifier of the current task
        :param pulumi.Input[builtins.str] link: Link to the task details
        :param pulumi.Input[builtins.str] status: Current global status of the current task
        :param pulumi.Input[builtins.str] type: Type of the current task
        """
        if id is not None:
            pulumi.set(__self__, "id", id)
        if link is not None:
            pulumi.set(__self__, "link", link)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Identifier of the current task
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def link(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Link to the task details
        """
        return pulumi.get(self, "link")

    @link.setter
    def link(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "link", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Current global status of the current task
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of the current task
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)


if not MYPY:
    class NameIamArgsDict(TypedDict):
        display_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Resource display name
        """
        id: NotRequired[pulumi.Input[builtins.str]]
        """
        Unique identifier of the resource
        """
        tags: NotRequired[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]
        """
        Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        urn: NotRequired[pulumi.Input[builtins.str]]
        """
        Unique resource name used in policies
        """
elif False:
    NameIamArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameIamArgs:
    def __init__(__self__, *,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 urn: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] display_name: Resource display name
        :param pulumi.Input[builtins.str] id: Unique identifier of the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Resource tags. Tags that were internally computed are prefixed with ovh:
        :param pulumi.Input[builtins.str] urn: Unique resource name used in policies
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if urn is not None:
            pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def urn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Unique resource name used in policies
        """
        return pulumi.get(self, "urn")

    @urn.setter
    def urn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urn", value)


if not MYPY:
    class NameOrderArgsDict(TypedDict):
        date: NotRequired[pulumi.Input[builtins.str]]
        details: NotRequired[pulumi.Input[Sequence[pulumi.Input['NameOrderDetailArgsDict']]]]
        expiration_date: NotRequired[pulumi.Input[builtins.str]]
        order_id: NotRequired[pulumi.Input[builtins.float]]
elif False:
    NameOrderArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameOrderArgs:
    def __init__(__self__, *,
                 date: Optional[pulumi.Input[builtins.str]] = None,
                 details: Optional[pulumi.Input[Sequence[pulumi.Input['NameOrderDetailArgs']]]] = None,
                 expiration_date: Optional[pulumi.Input[builtins.str]] = None,
                 order_id: Optional[pulumi.Input[builtins.float]] = None):
        if date is not None:
            pulumi.set(__self__, "date", date)
        if details is not None:
            pulumi.set(__self__, "details", details)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if order_id is not None:
            pulumi.set(__self__, "order_id", order_id)

    @property
    @pulumi.getter
    def date(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "date")

    @date.setter
    def date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "date", value)

    @property
    @pulumi.getter
    def details(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NameOrderDetailArgs']]]]:
        return pulumi.get(self, "details")

    @details.setter
    def details(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NameOrderDetailArgs']]]]):
        pulumi.set(self, "details", value)

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "expiration_date")

    @expiration_date.setter
    def expiration_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expiration_date", value)

    @property
    @pulumi.getter(name="orderId")
    def order_id(self) -> Optional[pulumi.Input[builtins.float]]:
        return pulumi.get(self, "order_id")

    @order_id.setter
    def order_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "order_id", value)


if not MYPY:
    class NameOrderDetailArgsDict(TypedDict):
        description: NotRequired[pulumi.Input[builtins.str]]
        detail_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Product type of item in order
        """
        domain: NotRequired[pulumi.Input[builtins.str]]
        order_detail_id: NotRequired[pulumi.Input[builtins.float]]
        quantity: NotRequired[pulumi.Input[builtins.str]]
elif False:
    NameOrderDetailArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameOrderDetailArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 detail_type: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 order_detail_id: Optional[pulumi.Input[builtins.float]] = None,
                 quantity: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] detail_type: Product type of item in order
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if detail_type is not None:
            pulumi.set(__self__, "detail_type", detail_type)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if order_detail_id is not None:
            pulumi.set(__self__, "order_detail_id", order_detail_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="detailType")
    def detail_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Product type of item in order
        """
        return pulumi.get(self, "detail_type")

    @detail_type.setter
    def detail_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "detail_type", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="orderDetailId")
    def order_detail_id(self) -> Optional[pulumi.Input[builtins.float]]:
        return pulumi.get(self, "order_detail_id")

    @order_detail_id.setter
    def order_detail_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "order_detail_id", value)

    @property
    @pulumi.getter
    def quantity(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "quantity", value)


if not MYPY:
    class NamePlanArgsDict(TypedDict):
        duration: pulumi.Input[builtins.str]
        """
        Duration selected for the purchase of the product (defaults to "P1Y")
        """
        plan_code: pulumi.Input[builtins.str]
        """
        Identifier of the option offer
        """
        pricing_mode: pulumi.Input[builtins.str]
        """
        Pricing mode selected for the purchase of the product
        """
        configurations: NotRequired[pulumi.Input[Sequence[pulumi.Input['NamePlanConfigurationArgsDict']]]]
        item_id: NotRequired[pulumi.Input[builtins.float]]
        """
        Cart item to be linked
        """
        quantity: NotRequired[pulumi.Input[builtins.float]]
        """
        Quantity of product desired
        """
elif False:
    NamePlanArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NamePlanArgs:
    def __init__(__self__, *,
                 duration: pulumi.Input[builtins.str],
                 plan_code: pulumi.Input[builtins.str],
                 pricing_mode: pulumi.Input[builtins.str],
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input['NamePlanConfigurationArgs']]]] = None,
                 item_id: Optional[pulumi.Input[builtins.float]] = None,
                 quantity: Optional[pulumi.Input[builtins.float]] = None):
        """
        :param pulumi.Input[builtins.str] duration: Duration selected for the purchase of the product (defaults to "P1Y")
        :param pulumi.Input[builtins.str] plan_code: Identifier of the option offer
        :param pulumi.Input[builtins.str] pricing_mode: Pricing mode selected for the purchase of the product
        :param pulumi.Input[builtins.float] item_id: Cart item to be linked
        :param pulumi.Input[builtins.float] quantity: Quantity of product desired
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)
        if item_id is not None:
            pulumi.set(__self__, "item_id", item_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Input[builtins.str]:
        """
        Duration selected for the purchase of the product (defaults to "P1Y")
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> pulumi.Input[builtins.str]:
        """
        Identifier of the option offer
        """
        return pulumi.get(self, "plan_code")

    @plan_code.setter
    def plan_code(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "plan_code", value)

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> pulumi.Input[builtins.str]:
        """
        Pricing mode selected for the purchase of the product
        """
        return pulumi.get(self, "pricing_mode")

    @pricing_mode.setter
    def pricing_mode(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "pricing_mode", value)

    @property
    @pulumi.getter
    def configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NamePlanConfigurationArgs']]]]:
        return pulumi.get(self, "configurations")

    @configurations.setter
    def configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NamePlanConfigurationArgs']]]]):
        pulumi.set(self, "configurations", value)

    @property
    @pulumi.getter(name="itemId")
    def item_id(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Cart item to be linked
        """
        return pulumi.get(self, "item_id")

    @item_id.setter
    def item_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "item_id", value)

    @property
    @pulumi.getter
    def quantity(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Quantity of product desired
        """
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "quantity", value)


if not MYPY:
    class NamePlanConfigurationArgsDict(TypedDict):
        label: pulumi.Input[builtins.str]
        """
        Label for your configuration item
        """
        value: pulumi.Input[builtins.str]
        """
        Value or resource URL on API.OVH.COM of your configuration item
        """
elif False:
    NamePlanConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NamePlanConfigurationArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[builtins.str],
                 value: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] label: Label for your configuration item
        :param pulumi.Input[builtins.str] value: Value or resource URL on API.OVH.COM of your configuration item
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> pulumi.Input[builtins.str]:
        """
        Label for your configuration item
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "label", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[builtins.str]:
        """
        Value or resource URL on API.OVH.COM of your configuration item
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "value", value)


if not MYPY:
    class NamePlanOptionArgsDict(TypedDict):
        duration: pulumi.Input[builtins.str]
        """
        Duration selected for the purchase of the product
        """
        plan_code: pulumi.Input[builtins.str]
        """
        Identifier of the option offer
        """
        pricing_mode: pulumi.Input[builtins.str]
        """
        Pricing mode selected for the purchase of the product
        """
        quantity: pulumi.Input[builtins.float]
        """
        Quantity of product desired
        """
        configurations: NotRequired[pulumi.Input[Sequence[pulumi.Input['NamePlanOptionConfigurationArgsDict']]]]
elif False:
    NamePlanOptionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NamePlanOptionArgs:
    def __init__(__self__, *,
                 duration: pulumi.Input[builtins.str],
                 plan_code: pulumi.Input[builtins.str],
                 pricing_mode: pulumi.Input[builtins.str],
                 quantity: pulumi.Input[builtins.float],
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input['NamePlanOptionConfigurationArgs']]]] = None):
        """
        :param pulumi.Input[builtins.str] duration: Duration selected for the purchase of the product
        :param pulumi.Input[builtins.str] plan_code: Identifier of the option offer
        :param pulumi.Input[builtins.str] pricing_mode: Pricing mode selected for the purchase of the product
        :param pulumi.Input[builtins.float] quantity: Quantity of product desired
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        pulumi.set(__self__, "quantity", quantity)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Input[builtins.str]:
        """
        Duration selected for the purchase of the product
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> pulumi.Input[builtins.str]:
        """
        Identifier of the option offer
        """
        return pulumi.get(self, "plan_code")

    @plan_code.setter
    def plan_code(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "plan_code", value)

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> pulumi.Input[builtins.str]:
        """
        Pricing mode selected for the purchase of the product
        """
        return pulumi.get(self, "pricing_mode")

    @pricing_mode.setter
    def pricing_mode(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "pricing_mode", value)

    @property
    @pulumi.getter
    def quantity(self) -> pulumi.Input[builtins.float]:
        """
        Quantity of product desired
        """
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: pulumi.Input[builtins.float]):
        pulumi.set(self, "quantity", value)

    @property
    @pulumi.getter
    def configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NamePlanOptionConfigurationArgs']]]]:
        return pulumi.get(self, "configurations")

    @configurations.setter
    def configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NamePlanOptionConfigurationArgs']]]]):
        pulumi.set(self, "configurations", value)


if not MYPY:
    class NamePlanOptionConfigurationArgsDict(TypedDict):
        label: pulumi.Input[builtins.str]
        """
        Label for your configuration item
        """
        value: pulumi.Input[builtins.str]
        """
        Value or resource URL on API.OVH.COM of your configuration item
        """
elif False:
    NamePlanOptionConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NamePlanOptionConfigurationArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[builtins.str],
                 value: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] label: Label for your configuration item
        :param pulumi.Input[builtins.str] value: Value or resource URL on API.OVH.COM of your configuration item
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> pulumi.Input[builtins.str]:
        """
        Label for your configuration item
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "label", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[builtins.str]:
        """
        Value or resource URL on API.OVH.COM of your configuration item
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "value", value)


if not MYPY:
    class NameServersServerArgsDict(TypedDict):
        host: pulumi.Input[builtins.str]
        """
        The server hostname
        """
        ip: NotRequired[pulumi.Input[builtins.str]]
        """
        The server IP
        """
elif False:
    NameServersServerArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameServersServerArgs:
    def __init__(__self__, *,
                 host: pulumi.Input[builtins.str],
                 ip: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] host: The server hostname
        :param pulumi.Input[builtins.str] ip: The server IP
        """
        pulumi.set(__self__, "host", host)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)

    @property
    @pulumi.getter
    def host(self) -> pulumi.Input[builtins.str]:
        """
        The server hostname
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The server IP
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)


if not MYPY:
    class NameTargetSpecArgsDict(TypedDict):
        dns_configuration: NotRequired[pulumi.Input['NameTargetSpecDnsConfigurationArgsDict']]
        """
        The domain DNS configuration
        """
elif False:
    NameTargetSpecArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameTargetSpecArgs:
    def __init__(__self__, *,
                 dns_configuration: Optional[pulumi.Input['NameTargetSpecDnsConfigurationArgs']] = None):
        """
        :param pulumi.Input['NameTargetSpecDnsConfigurationArgs'] dns_configuration: The domain DNS configuration
        """
        if dns_configuration is not None:
            pulumi.set(__self__, "dns_configuration", dns_configuration)

    @property
    @pulumi.getter(name="dnsConfiguration")
    def dns_configuration(self) -> Optional[pulumi.Input['NameTargetSpecDnsConfigurationArgs']]:
        """
        The domain DNS configuration
        """
        return pulumi.get(self, "dns_configuration")

    @dns_configuration.setter
    def dns_configuration(self, value: Optional[pulumi.Input['NameTargetSpecDnsConfigurationArgs']]):
        pulumi.set(self, "dns_configuration", value)


if not MYPY:
    class NameTargetSpecDnsConfigurationArgsDict(TypedDict):
        name_servers: NotRequired[pulumi.Input[Sequence[pulumi.Input['NameTargetSpecDnsConfigurationNameServerArgsDict']]]]
        """
        The name servers to update
        """
elif False:
    NameTargetSpecDnsConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameTargetSpecDnsConfigurationArgs:
    def __init__(__self__, *,
                 name_servers: Optional[pulumi.Input[Sequence[pulumi.Input['NameTargetSpecDnsConfigurationNameServerArgs']]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['NameTargetSpecDnsConfigurationNameServerArgs']]] name_servers: The name servers to update
        """
        if name_servers is not None:
            pulumi.set(__self__, "name_servers", name_servers)

    @property
    @pulumi.getter(name="nameServers")
    def name_servers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NameTargetSpecDnsConfigurationNameServerArgs']]]]:
        """
        The name servers to update
        """
        return pulumi.get(self, "name_servers")

    @name_servers.setter
    def name_servers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NameTargetSpecDnsConfigurationNameServerArgs']]]]):
        pulumi.set(self, "name_servers", value)


if not MYPY:
    class NameTargetSpecDnsConfigurationNameServerArgsDict(TypedDict):
        ipv4: NotRequired[pulumi.Input[builtins.str]]
        """
        The IPv4 associated to the name server
        """
        ipv6: NotRequired[pulumi.Input[builtins.str]]
        """
        The IPv6 associated to the name server
        """
        name_server: NotRequired[pulumi.Input[builtins.str]]
        """
        The host name
        """
elif False:
    NameTargetSpecDnsConfigurationNameServerArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class NameTargetSpecDnsConfigurationNameServerArgs:
    def __init__(__self__, *,
                 ipv4: Optional[pulumi.Input[builtins.str]] = None,
                 ipv6: Optional[pulumi.Input[builtins.str]] = None,
                 name_server: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] ipv4: The IPv4 associated to the name server
        :param pulumi.Input[builtins.str] ipv6: The IPv6 associated to the name server
        :param pulumi.Input[builtins.str] name_server: The host name
        """
        if ipv4 is not None:
            pulumi.set(__self__, "ipv4", ipv4)
        if ipv6 is not None:
            pulumi.set(__self__, "ipv6", ipv6)
        if name_server is not None:
            pulumi.set(__self__, "name_server", name_server)

    @property
    @pulumi.getter
    def ipv4(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IPv4 associated to the name server
        """
        return pulumi.get(self, "ipv4")

    @ipv4.setter
    def ipv4(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv4", value)

    @property
    @pulumi.getter
    def ipv6(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IPv6 associated to the name server
        """
        return pulumi.get(self, "ipv6")

    @ipv6.setter
    def ipv6(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ipv6", value)

    @property
    @pulumi.getter(name="nameServer")
    def name_server(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The host name
        """
        return pulumi.get(self, "name_server")

    @name_server.setter
    def name_server(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name_server", value)


if not MYPY:
    class ZoneOrderArgsDict(TypedDict):
        date: NotRequired[pulumi.Input[builtins.str]]
        """
        date
        """
        details: NotRequired[pulumi.Input[Sequence[pulumi.Input['ZoneOrderDetailArgsDict']]]]
        """
        Information about a Bill entry
        """
        expiration_date: NotRequired[pulumi.Input[builtins.str]]
        """
        expiration date
        """
        order_id: NotRequired[pulumi.Input[builtins.int]]
        """
        order id
        """
elif False:
    ZoneOrderArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ZoneOrderArgs:
    def __init__(__self__, *,
                 date: Optional[pulumi.Input[builtins.str]] = None,
                 details: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneOrderDetailArgs']]]] = None,
                 expiration_date: Optional[pulumi.Input[builtins.str]] = None,
                 order_id: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.str] date: date
        :param pulumi.Input[Sequence[pulumi.Input['ZoneOrderDetailArgs']]] details: Information about a Bill entry
        :param pulumi.Input[builtins.str] expiration_date: expiration date
        :param pulumi.Input[builtins.int] order_id: order id
        """
        if date is not None:
            pulumi.set(__self__, "date", date)
        if details is not None:
            pulumi.set(__self__, "details", details)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if order_id is not None:
            pulumi.set(__self__, "order_id", order_id)

    @property
    @pulumi.getter
    def date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        date
        """
        return pulumi.get(self, "date")

    @date.setter
    def date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "date", value)

    @property
    @pulumi.getter
    def details(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZoneOrderDetailArgs']]]]:
        """
        Information about a Bill entry
        """
        return pulumi.get(self, "details")

    @details.setter
    def details(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZoneOrderDetailArgs']]]]):
        pulumi.set(self, "details", value)

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        expiration date
        """
        return pulumi.get(self, "expiration_date")

    @expiration_date.setter
    def expiration_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expiration_date", value)

    @property
    @pulumi.getter(name="orderId")
    def order_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        order id
        """
        return pulumi.get(self, "order_id")

    @order_id.setter
    def order_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "order_id", value)


if not MYPY:
    class ZoneOrderDetailArgsDict(TypedDict):
        description: NotRequired[pulumi.Input[builtins.str]]
        """
        description
        """
        domain: NotRequired[pulumi.Input[builtins.str]]
        """
        expiration date
        """
        order_detail_id: NotRequired[pulumi.Input[builtins.int]]
        """
        order detail id
        """
        quantity: NotRequired[pulumi.Input[builtins.str]]
        """
        quantity
        """
elif False:
    ZoneOrderDetailArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ZoneOrderDetailArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 order_detail_id: Optional[pulumi.Input[builtins.int]] = None,
                 quantity: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] description: description
        :param pulumi.Input[builtins.str] domain: expiration date
        :param pulumi.Input[builtins.int] order_detail_id: order detail id
        :param pulumi.Input[builtins.str] quantity: quantity
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if order_detail_id is not None:
            pulumi.set(__self__, "order_detail_id", order_detail_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        expiration date
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="orderDetailId")
    def order_detail_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        order detail id
        """
        return pulumi.get(self, "order_detail_id")

    @order_detail_id.setter
    def order_detail_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "order_detail_id", value)

    @property
    @pulumi.getter
    def quantity(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        quantity
        """
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "quantity", value)


if not MYPY:
    class ZonePlanArgsDict(TypedDict):
        duration: pulumi.Input[builtins.str]
        """
        duration
        """
        plan_code: pulumi.Input[builtins.str]
        """
        Plan code
        """
        pricing_mode: pulumi.Input[builtins.str]
        """
        Pricing model identifier
        """
        catalog_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Catalog name
        """
        configurations: NotRequired[pulumi.Input[Sequence[pulumi.Input['ZonePlanConfigurationArgsDict']]]]
        """
        Representation of a configuration item for personalizing product. 2 configurations are required : one for `zone` and one for `template`
        """
elif False:
    ZonePlanArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ZonePlanArgs:
    def __init__(__self__, *,
                 duration: pulumi.Input[builtins.str],
                 plan_code: pulumi.Input[builtins.str],
                 pricing_mode: pulumi.Input[builtins.str],
                 catalog_name: Optional[pulumi.Input[builtins.str]] = None,
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input['ZonePlanConfigurationArgs']]]] = None):
        """
        :param pulumi.Input[builtins.str] duration: duration
        :param pulumi.Input[builtins.str] plan_code: Plan code
        :param pulumi.Input[builtins.str] pricing_mode: Pricing model identifier
        :param pulumi.Input[builtins.str] catalog_name: Catalog name
        :param pulumi.Input[Sequence[pulumi.Input['ZonePlanConfigurationArgs']]] configurations: Representation of a configuration item for personalizing product. 2 configurations are required : one for `zone` and one for `template`
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Input[builtins.str]:
        """
        duration
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> pulumi.Input[builtins.str]:
        """
        Plan code
        """
        return pulumi.get(self, "plan_code")

    @plan_code.setter
    def plan_code(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "plan_code", value)

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> pulumi.Input[builtins.str]:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @pricing_mode.setter
    def pricing_mode(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "pricing_mode", value)

    @property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Catalog name
        """
        return pulumi.get(self, "catalog_name")

    @catalog_name.setter
    def catalog_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "catalog_name", value)

    @property
    @pulumi.getter
    def configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZonePlanConfigurationArgs']]]]:
        """
        Representation of a configuration item for personalizing product. 2 configurations are required : one for `zone` and one for `template`
        """
        return pulumi.get(self, "configurations")

    @configurations.setter
    def configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZonePlanConfigurationArgs']]]]):
        pulumi.set(self, "configurations", value)


if not MYPY:
    class ZonePlanConfigurationArgsDict(TypedDict):
        label: pulumi.Input[builtins.str]
        """
        Identifier of the resource : `zone` or `template`
        """
        value: pulumi.Input[builtins.str]
        """
        For `zone`, the value is the zone name `myzone.example.com`. For `template`, the value can be `basic`, `minimized` or `redirect` which is the same as `minimized` with additional entries for a redirect configuration.
        """
elif False:
    ZonePlanConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ZonePlanConfigurationArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[builtins.str],
                 value: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] label: Identifier of the resource : `zone` or `template`
        :param pulumi.Input[builtins.str] value: For `zone`, the value is the zone name `myzone.example.com`. For `template`, the value can be `basic`, `minimized` or `redirect` which is the same as `minimized` with additional entries for a redirect configuration.
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> pulumi.Input[builtins.str]:
        """
        Identifier of the resource : `zone` or `template`
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "label", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[builtins.str]:
        """
        For `zone`, the value is the zone name `myzone.example.com`. For `template`, the value can be `basic`, `minimized` or `redirect` which is the same as `minimized` with additional entries for a redirect configuration.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "value", value)


if not MYPY:
    class ZonePlanOptionArgsDict(TypedDict):
        duration: pulumi.Input[builtins.str]
        """
        duration
        """
        plan_code: pulumi.Input[builtins.str]
        """
        Plan code
        """
        pricing_mode: pulumi.Input[builtins.str]
        """
        Pricing model identifier
        """
        catalog_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Catalog name
        """
        configurations: NotRequired[pulumi.Input[Sequence[pulumi.Input['ZonePlanOptionConfigurationArgsDict']]]]
        """
        Representation of a configuration item for personalizing product
        """
elif False:
    ZonePlanOptionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ZonePlanOptionArgs:
    def __init__(__self__, *,
                 duration: pulumi.Input[builtins.str],
                 plan_code: pulumi.Input[builtins.str],
                 pricing_mode: pulumi.Input[builtins.str],
                 catalog_name: Optional[pulumi.Input[builtins.str]] = None,
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input['ZonePlanOptionConfigurationArgs']]]] = None):
        """
        :param pulumi.Input[builtins.str] duration: duration
        :param pulumi.Input[builtins.str] plan_code: Plan code
        :param pulumi.Input[builtins.str] pricing_mode: Pricing model identifier
        :param pulumi.Input[builtins.str] catalog_name: Catalog name
        :param pulumi.Input[Sequence[pulumi.Input['ZonePlanOptionConfigurationArgs']]] configurations: Representation of a configuration item for personalizing product
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Input[builtins.str]:
        """
        duration
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> pulumi.Input[builtins.str]:
        """
        Plan code
        """
        return pulumi.get(self, "plan_code")

    @plan_code.setter
    def plan_code(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "plan_code", value)

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> pulumi.Input[builtins.str]:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @pricing_mode.setter
    def pricing_mode(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "pricing_mode", value)

    @property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Catalog name
        """
        return pulumi.get(self, "catalog_name")

    @catalog_name.setter
    def catalog_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "catalog_name", value)

    @property
    @pulumi.getter
    def configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ZonePlanOptionConfigurationArgs']]]]:
        """
        Representation of a configuration item for personalizing product
        """
        return pulumi.get(self, "configurations")

    @configurations.setter
    def configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ZonePlanOptionConfigurationArgs']]]]):
        pulumi.set(self, "configurations", value)


if not MYPY:
    class ZonePlanOptionConfigurationArgsDict(TypedDict):
        label: pulumi.Input[builtins.str]
        """
        Identifier of the resource
        """
        value: pulumi.Input[builtins.str]
        """
        Path to the resource in API.OVH.COM
        """
elif False:
    ZonePlanOptionConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ZonePlanOptionConfigurationArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[builtins.str],
                 value: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] label: Identifier of the resource
        :param pulumi.Input[builtins.str] value: Path to the resource in API.OVH.COM
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> pulumi.Input[builtins.str]:
        """
        Identifier of the resource
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "label", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[builtins.str]:
        """
        Path to the resource in API.OVH.COM
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "value", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'OpensearchUserAclArgs',
    'OpensearchUserAclArgsDict',
    'PrometheusTargetArgs',
    'PrometheusTargetArgsDict',
]

MYPY = False

if not MYPY:
    class OpensearchUserAclArgsDict(TypedDict):
        pattern: pulumi.Input[builtins.str]
        """
        Pattern of the ACL.
        """
        permission: pulumi.Input[builtins.str]
        """
        Permission of the ACL Available permission:
        """
elif False:
    OpensearchUserAclArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class OpensearchUserAclArgs:
    def __init__(__self__, *,
                 pattern: pulumi.Input[builtins.str],
                 permission: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] pattern: Pattern of the ACL.
        :param pulumi.Input[builtins.str] permission: Permission of the ACL Available permission:
        """
        pulumi.set(__self__, "pattern", pattern)
        pulumi.set(__self__, "permission", permission)

    @property
    @pulumi.getter
    def pattern(self) -> pulumi.Input[builtins.str]:
        """
        Pattern of the ACL.
        """
        return pulumi.get(self, "pattern")

    @pattern.setter
    def pattern(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "pattern", value)

    @property
    @pulumi.getter
    def permission(self) -> pulumi.Input[builtins.str]:
        """
        Permission of the ACL Available permission:
        """
        return pulumi.get(self, "permission")

    @permission.setter
    def permission(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "permission", value)


if not MYPY:
    class PrometheusTargetArgsDict(TypedDict):
        host: NotRequired[pulumi.Input[builtins.str]]
        """
        Host of the endpoint
        """
        port: NotRequired[pulumi.Input[builtins.int]]
        """
        Connection port for the endpoint
        """
elif False:
    PrometheusTargetArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PrometheusTargetArgs:
    def __init__(__self__, *,
                 host: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.str] host: Host of the endpoint
        :param pulumi.Input[builtins.int] port: Connection port for the endpoint
        """
        if host is not None:
            pulumi.set(__self__, "host", host)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def host(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Host of the endpoint
        """
        return pulumi.get(self, "host")

    @host.setter
    def host(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "host", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Connection port for the endpoint
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetUserS3CredentialsResult',
    'AwaitableGetUserS3CredentialsResult',
    'get_user_s3_credentials',
    'get_user_s3_credentials_output',
]

@pulumi.output_type
class GetUserS3CredentialsResult:
    """
    A collection of values returned by getUserS3Credentials.
    """
    def __init__(__self__, access_key_ids=None, id=None, service_name=None, user_id=None):
        if access_key_ids and not isinstance(access_key_ids, list):
            raise TypeError("Expected argument 'access_key_ids' to be a list")
        pulumi.set(__self__, "access_key_ids", access_key_ids)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="accessKeyIds")
    def access_key_ids(self) -> Sequence[builtins.str]:
        """
        The list of the Access Key ID associated with this user.
        """
        return pulumi.get(self, "access_key_ids")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> builtins.str:
        return pulumi.get(self, "user_id")


class AwaitableGetUserS3CredentialsResult(GetUserS3CredentialsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserS3CredentialsResult(
            access_key_ids=self.access_key_ids,
            id=self.id,
            service_name=self.service_name,
            user_id=self.user_id)


def get_user_s3_credentials(service_name: Optional[builtins.str] = None,
                            user_id: Optional[builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserS3CredentialsResult:
    """
    Use this data source to retrieve the list of all the S3 access_key_id associated with a public cloud project's user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_s3_credentials = ovh.CloudProject.get_user_s3_credentials(service_name="XXXXXX",
        user_id="1234")
    pulumi.export("accessKeyIds", my_s3_credentials.access_key_ids)
    ```


    :param builtins.str service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    :param builtins.str user_id: The ID of a public cloud project's user.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getUserS3Credentials:getUserS3Credentials', __args__, opts=opts, typ=GetUserS3CredentialsResult).value

    return AwaitableGetUserS3CredentialsResult(
        access_key_ids=pulumi.get(__ret__, 'access_key_ids'),
        id=pulumi.get(__ret__, 'id'),
        service_name=pulumi.get(__ret__, 'service_name'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_user_s3_credentials_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                                   user_id: Optional[pulumi.Input[builtins.str]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserS3CredentialsResult]:
    """
    Use this data source to retrieve the list of all the S3 access_key_id associated with a public cloud project's user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_s3_credentials = ovh.CloudProject.get_user_s3_credentials(service_name="XXXXXX",
        user_id="1234")
    pulumi.export("accessKeyIds", my_s3_credentials.access_key_ids)
    ```


    :param builtins.str service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    :param builtins.str user_id: The ID of a public cloud project's user.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getUserS3Credentials:getUserS3Credentials', __args__, opts=opts, typ=GetUserS3CredentialsResult)
    return __ret__.apply(lambda __response__: GetUserS3CredentialsResult(
        access_key_ids=pulumi.get(__response__, 'access_key_ids'),
        id=pulumi.get(__response__, 'id'),
        service_name=pulumi.get(__response__, 'service_name'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServerSpecificationsNetworkResult',
    'AwaitableGetServerSpecificationsNetworkResult',
    'get_server_specifications_network',
    'get_server_specifications_network_output',
]

@pulumi.output_type
class GetServerSpecificationsNetworkResult:
    """
    A collection of values returned by getServerSpecificationsNetwork.
    """
    def __init__(__self__, bandwidth=None, connection_val=None, id=None, ola=None, routing=None, service_name=None, switching=None, traffic=None, vmac=None, vrack=None):
        if bandwidth and not isinstance(bandwidth, dict):
            raise TypeError("Expected argument 'bandwidth' to be a dict")
        pulumi.set(__self__, "bandwidth", bandwidth)
        if connection_val and not isinstance(connection_val, dict):
            raise TypeError("Expected argument 'connection_val' to be a dict")
        pulumi.set(__self__, "connection_val", connection_val)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ola and not isinstance(ola, dict):
            raise TypeError("Expected argument 'ola' to be a dict")
        pulumi.set(__self__, "ola", ola)
        if routing and not isinstance(routing, dict):
            raise TypeError("Expected argument 'routing' to be a dict")
        pulumi.set(__self__, "routing", routing)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if switching and not isinstance(switching, dict):
            raise TypeError("Expected argument 'switching' to be a dict")
        pulumi.set(__self__, "switching", switching)
        if traffic and not isinstance(traffic, dict):
            raise TypeError("Expected argument 'traffic' to be a dict")
        pulumi.set(__self__, "traffic", traffic)
        if vmac and not isinstance(vmac, dict):
            raise TypeError("Expected argument 'vmac' to be a dict")
        pulumi.set(__self__, "vmac", vmac)
        if vrack and not isinstance(vrack, dict):
            raise TypeError("Expected argument 'vrack' to be a dict")
        pulumi.set(__self__, "vrack", vrack)

    @property
    @pulumi.getter
    def bandwidth(self) -> 'outputs.GetServerSpecificationsNetworkBandwidthResult':
        """
        vrack bandwidth limitation
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="connectionVal")
    def connection_val(self) -> 'outputs.GetServerSpecificationsNetworkConnectionValResult':
        """
        Network connection flow rate
        """
        return pulumi.get(self, "connection_val")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ola(self) -> 'outputs.GetServerSpecificationsNetworkOlaResult':
        """
        OLA details
        """
        return pulumi.get(self, "ola")

    @property
    @pulumi.getter
    def routing(self) -> 'outputs.GetServerSpecificationsNetworkRoutingResult':
        """
        Routing details
        """
        return pulumi.get(self, "routing")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def switching(self) -> 'outputs.GetServerSpecificationsNetworkSwitchingResult':
        """
        Switching details
        """
        return pulumi.get(self, "switching")

    @property
    @pulumi.getter
    def traffic(self) -> 'outputs.GetServerSpecificationsNetworkTrafficResult':
        """
        Traffic details
        """
        return pulumi.get(self, "traffic")

    @property
    @pulumi.getter
    def vmac(self) -> 'outputs.GetServerSpecificationsNetworkVmacResult':
        """
        VMAC information for this dedicated server
        """
        return pulumi.get(self, "vmac")

    @property
    @pulumi.getter
    def vrack(self) -> 'outputs.GetServerSpecificationsNetworkVrackResult':
        """
        vRack details
        """
        return pulumi.get(self, "vrack")


class AwaitableGetServerSpecificationsNetworkResult(GetServerSpecificationsNetworkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerSpecificationsNetworkResult(
            bandwidth=self.bandwidth,
            connection_val=self.connection_val,
            id=self.id,
            ola=self.ola,
            routing=self.routing,
            service_name=self.service_name,
            switching=self.switching,
            traffic=self.traffic,
            vmac=self.vmac,
            vrack=self.vrack)


def get_server_specifications_network(service_name: Optional[builtins.str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerSpecificationsNetworkResult:
    """
    Use this data source to get the network information about a dedicated server associated with your OVHcloud Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    spec = ovh.Dedicated.get_server_specifications_network(service_name="myserver")
    ```


    :param builtins.str service_name: The internal name of your dedicated server.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Dedicated/getServerSpecificationsNetwork:getServerSpecificationsNetwork', __args__, opts=opts, typ=GetServerSpecificationsNetworkResult).value

    return AwaitableGetServerSpecificationsNetworkResult(
        bandwidth=pulumi.get(__ret__, 'bandwidth'),
        connection_val=pulumi.get(__ret__, 'connection_val'),
        id=pulumi.get(__ret__, 'id'),
        ola=pulumi.get(__ret__, 'ola'),
        routing=pulumi.get(__ret__, 'routing'),
        service_name=pulumi.get(__ret__, 'service_name'),
        switching=pulumi.get(__ret__, 'switching'),
        traffic=pulumi.get(__ret__, 'traffic'),
        vmac=pulumi.get(__ret__, 'vmac'),
        vrack=pulumi.get(__ret__, 'vrack'))
def get_server_specifications_network_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServerSpecificationsNetworkResult]:
    """
    Use this data source to get the network information about a dedicated server associated with your OVHcloud Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    spec = ovh.Dedicated.get_server_specifications_network(service_name="myserver")
    ```


    :param builtins.str service_name: The internal name of your dedicated server.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Dedicated/getServerSpecificationsNetwork:getServerSpecificationsNetwork', __args__, opts=opts, typ=GetServerSpecificationsNetworkResult)
    return __ret__.apply(lambda __response__: GetServerSpecificationsNetworkResult(
        bandwidth=pulumi.get(__response__, 'bandwidth'),
        connection_val=pulumi.get(__response__, 'connection_val'),
        id=pulumi.get(__response__, 'id'),
        ola=pulumi.get(__response__, 'ola'),
        routing=pulumi.get(__response__, 'routing'),
        service_name=pulumi.get(__response__, 'service_name'),
        switching=pulumi.get(__response__, 'switching'),
        traffic=pulumi.get(__response__, 'traffic'),
        vmac=pulumi.get(__response__, 'vmac'),
        vrack=pulumi.get(__response__, 'vrack')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['M3DbNamespaceArgs', 'M3DbNamespace']

@pulumi.input_type
class M3DbNamespaceArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 resolution: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 retention_block_data_expiration_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_block_size_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_buffer_future_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_buffer_past_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_period_duration: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 writes_to_commit_log_enabled: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a M3DbNamespace resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] resolution: Resolution for an aggregated namespace. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] name: Name of the namespace. A namespace named "default" is mapped with already created default namespace instead of creating a new namespace.
        :param pulumi.Input[builtins.str] retention_block_data_expiration_duration: Controls how long we wait before expiring stale data. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_block_size_duration: Controls how long to keep a block in memory before flushing to a fileset on disk. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_buffer_future_duration: Controls how far into the future writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_buffer_past_duration: Controls how far into the past writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_period_duration: Controls the duration of time that M3DB will retain data for the namespace. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.bool] snapshot_enabled: Defines whether M3DB will create snapshot files for this namespace.
        :param pulumi.Input[builtins.bool] writes_to_commit_log_enabled: Defines whether M3DB will include writes to this namespace in the commit log.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "resolution", resolution)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if retention_block_data_expiration_duration is not None:
            pulumi.set(__self__, "retention_block_data_expiration_duration", retention_block_data_expiration_duration)
        if retention_block_size_duration is not None:
            pulumi.set(__self__, "retention_block_size_duration", retention_block_size_duration)
        if retention_buffer_future_duration is not None:
            pulumi.set(__self__, "retention_buffer_future_duration", retention_buffer_future_duration)
        if retention_buffer_past_duration is not None:
            pulumi.set(__self__, "retention_buffer_past_duration", retention_buffer_past_duration)
        if retention_period_duration is not None:
            pulumi.set(__self__, "retention_period_duration", retention_period_duration)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if snapshot_enabled is not None:
            pulumi.set(__self__, "snapshot_enabled", snapshot_enabled)
        if writes_to_commit_log_enabled is not None:
            pulumi.set(__self__, "writes_to_commit_log_enabled", writes_to_commit_log_enabled)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def resolution(self) -> pulumi.Input[builtins.str]:
        """
        Resolution for an aggregated namespace. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "resolution")

    @resolution.setter
    def resolution(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resolution", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the namespace. A namespace named "default" is mapped with already created default namespace instead of creating a new namespace.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="retentionBlockDataExpirationDuration")
    def retention_block_data_expiration_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Controls how long we wait before expiring stale data. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_block_data_expiration_duration")

    @retention_block_data_expiration_duration.setter
    def retention_block_data_expiration_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_block_data_expiration_duration", value)

    @property
    @pulumi.getter(name="retentionBlockSizeDuration")
    def retention_block_size_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Controls how long to keep a block in memory before flushing to a fileset on disk. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_block_size_duration")

    @retention_block_size_duration.setter
    def retention_block_size_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_block_size_duration", value)

    @property
    @pulumi.getter(name="retentionBufferFutureDuration")
    def retention_buffer_future_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Controls how far into the future writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_buffer_future_duration")

    @retention_buffer_future_duration.setter
    def retention_buffer_future_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_buffer_future_duration", value)

    @property
    @pulumi.getter(name="retentionBufferPastDuration")
    def retention_buffer_past_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Controls how far into the past writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_buffer_past_duration")

    @retention_buffer_past_duration.setter
    def retention_buffer_past_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_buffer_past_duration", value)

    @property
    @pulumi.getter(name="retentionPeriodDuration")
    def retention_period_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Controls the duration of time that M3DB will retain data for the namespace. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_period_duration")

    @retention_period_duration.setter
    def retention_period_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_period_duration", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="snapshotEnabled")
    def snapshot_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether M3DB will create snapshot files for this namespace.
        """
        return pulumi.get(self, "snapshot_enabled")

    @snapshot_enabled.setter
    def snapshot_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "snapshot_enabled", value)

    @property
    @pulumi.getter(name="writesToCommitLogEnabled")
    def writes_to_commit_log_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether M3DB will include writes to this namespace in the commit log.
        """
        return pulumi.get(self, "writes_to_commit_log_enabled")

    @writes_to_commit_log_enabled.setter
    def writes_to_commit_log_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "writes_to_commit_log_enabled", value)


@pulumi.input_type
class _M3DbNamespaceState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resolution: Optional[pulumi.Input[builtins.str]] = None,
                 retention_block_data_expiration_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_block_size_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_buffer_future_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_buffer_past_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_period_duration: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 writes_to_commit_log_enabled: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering M3DbNamespace resources.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] name: Name of the namespace. A namespace named "default" is mapped with already created default namespace instead of creating a new namespace.
        :param pulumi.Input[builtins.str] resolution: Resolution for an aggregated namespace. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_block_data_expiration_duration: Controls how long we wait before expiring stale data. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_block_size_duration: Controls how long to keep a block in memory before flushing to a fileset on disk. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_buffer_future_duration: Controls how far into the future writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_buffer_past_duration: Controls how far into the past writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_period_duration: Controls the duration of time that M3DB will retain data for the namespace. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.bool] snapshot_enabled: Defines whether M3DB will create snapshot files for this namespace.
        :param pulumi.Input[builtins.str] type: Type of namespace.
        :param pulumi.Input[builtins.bool] writes_to_commit_log_enabled: Defines whether M3DB will include writes to this namespace in the commit log.
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resolution is not None:
            pulumi.set(__self__, "resolution", resolution)
        if retention_block_data_expiration_duration is not None:
            pulumi.set(__self__, "retention_block_data_expiration_duration", retention_block_data_expiration_duration)
        if retention_block_size_duration is not None:
            pulumi.set(__self__, "retention_block_size_duration", retention_block_size_duration)
        if retention_buffer_future_duration is not None:
            pulumi.set(__self__, "retention_buffer_future_duration", retention_buffer_future_duration)
        if retention_buffer_past_duration is not None:
            pulumi.set(__self__, "retention_buffer_past_duration", retention_buffer_past_duration)
        if retention_period_duration is not None:
            pulumi.set(__self__, "retention_period_duration", retention_period_duration)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if snapshot_enabled is not None:
            pulumi.set(__self__, "snapshot_enabled", snapshot_enabled)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if writes_to_commit_log_enabled is not None:
            pulumi.set(__self__, "writes_to_commit_log_enabled", writes_to_commit_log_enabled)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the namespace. A namespace named "default" is mapped with already created default namespace instead of creating a new namespace.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def resolution(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resolution for an aggregated namespace. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "resolution")

    @resolution.setter
    def resolution(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resolution", value)

    @property
    @pulumi.getter(name="retentionBlockDataExpirationDuration")
    def retention_block_data_expiration_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Controls how long we wait before expiring stale data. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_block_data_expiration_duration")

    @retention_block_data_expiration_duration.setter
    def retention_block_data_expiration_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_block_data_expiration_duration", value)

    @property
    @pulumi.getter(name="retentionBlockSizeDuration")
    def retention_block_size_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Controls how long to keep a block in memory before flushing to a fileset on disk. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_block_size_duration")

    @retention_block_size_duration.setter
    def retention_block_size_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_block_size_duration", value)

    @property
    @pulumi.getter(name="retentionBufferFutureDuration")
    def retention_buffer_future_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Controls how far into the future writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_buffer_future_duration")

    @retention_buffer_future_duration.setter
    def retention_buffer_future_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_buffer_future_duration", value)

    @property
    @pulumi.getter(name="retentionBufferPastDuration")
    def retention_buffer_past_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Controls how far into the past writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_buffer_past_duration")

    @retention_buffer_past_duration.setter
    def retention_buffer_past_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_buffer_past_duration", value)

    @property
    @pulumi.getter(name="retentionPeriodDuration")
    def retention_period_duration(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Controls the duration of time that M3DB will retain data for the namespace. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_period_duration")

    @retention_period_duration.setter
    def retention_period_duration(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_period_duration", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="snapshotEnabled")
    def snapshot_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether M3DB will create snapshot files for this namespace.
        """
        return pulumi.get(self, "snapshot_enabled")

    @snapshot_enabled.setter
    def snapshot_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "snapshot_enabled", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Type of namespace.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="writesToCommitLogEnabled")
    def writes_to_commit_log_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether M3DB will include writes to this namespace in the commit log.
        """
        return pulumi.get(self, "writes_to_commit_log_enabled")

    @writes_to_commit_log_enabled.setter
    def writes_to_commit_log_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "writes_to_commit_log_enabled", value)


@pulumi.type_token("ovh:CloudProjectDatabase/m3DbNamespace:M3DbNamespace")
class M3DbNamespace(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resolution: Optional[pulumi.Input[builtins.str]] = None,
                 retention_block_data_expiration_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_block_size_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_buffer_future_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_buffer_past_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_period_duration: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 writes_to_commit_log_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        Creates a namespace for a M3DB cluster associated with a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        m3db = ovh.CloudProjectDatabase.get_database(service_name="XXX",
            engine="m3db",
            id="ZZZ")
        namespace = ovh.cloud_project_database.M3DbNamespace("namespace",
            service_name=m3db.service_name,
            cluster_id=m3db.id,
            name="mynamespace",
            resolution="P2D",
            retention_period_duration="PT48H")
        ```

        ## Import

        OVHcloud Managed M3DB clusters namespaces can be imported using the `service_name`, `cluster_id` and `id` of the namespace, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/m3DbNamespace:M3DbNamespace my_namespace service_name/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] name: Name of the namespace. A namespace named "default" is mapped with already created default namespace instead of creating a new namespace.
        :param pulumi.Input[builtins.str] resolution: Resolution for an aggregated namespace. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_block_data_expiration_duration: Controls how long we wait before expiring stale data. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_block_size_duration: Controls how long to keep a block in memory before flushing to a fileset on disk. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_buffer_future_duration: Controls how far into the future writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_buffer_past_duration: Controls how far into the past writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_period_duration: Controls the duration of time that M3DB will retain data for the namespace. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.bool] snapshot_enabled: Defines whether M3DB will create snapshot files for this namespace.
        :param pulumi.Input[builtins.bool] writes_to_commit_log_enabled: Defines whether M3DB will include writes to this namespace in the commit log.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: M3DbNamespaceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a namespace for a M3DB cluster associated with a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        m3db = ovh.CloudProjectDatabase.get_database(service_name="XXX",
            engine="m3db",
            id="ZZZ")
        namespace = ovh.cloud_project_database.M3DbNamespace("namespace",
            service_name=m3db.service_name,
            cluster_id=m3db.id,
            name="mynamespace",
            resolution="P2D",
            retention_period_duration="PT48H")
        ```

        ## Import

        OVHcloud Managed M3DB clusters namespaces can be imported using the `service_name`, `cluster_id` and `id` of the namespace, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/m3DbNamespace:M3DbNamespace my_namespace service_name/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param M3DbNamespaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(M3DbNamespaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resolution: Optional[pulumi.Input[builtins.str]] = None,
                 retention_block_data_expiration_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_block_size_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_buffer_future_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_buffer_past_duration: Optional[pulumi.Input[builtins.str]] = None,
                 retention_period_duration: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 snapshot_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 writes_to_commit_log_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = M3DbNamespaceArgs.__new__(M3DbNamespaceArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["name"] = name
            if resolution is None and not opts.urn:
                raise TypeError("Missing required property 'resolution'")
            __props__.__dict__["resolution"] = resolution
            __props__.__dict__["retention_block_data_expiration_duration"] = retention_block_data_expiration_duration
            __props__.__dict__["retention_block_size_duration"] = retention_block_size_duration
            __props__.__dict__["retention_buffer_future_duration"] = retention_buffer_future_duration
            __props__.__dict__["retention_buffer_past_duration"] = retention_buffer_past_duration
            __props__.__dict__["retention_period_duration"] = retention_period_duration
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["snapshot_enabled"] = snapshot_enabled
            __props__.__dict__["writes_to_commit_log_enabled"] = writes_to_commit_log_enabled
            __props__.__dict__["type"] = None
        super(M3DbNamespace, __self__).__init__(
            'ovh:CloudProjectDatabase/m3DbNamespace:M3DbNamespace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            resolution: Optional[pulumi.Input[builtins.str]] = None,
            retention_block_data_expiration_duration: Optional[pulumi.Input[builtins.str]] = None,
            retention_block_size_duration: Optional[pulumi.Input[builtins.str]] = None,
            retention_buffer_future_duration: Optional[pulumi.Input[builtins.str]] = None,
            retention_buffer_past_duration: Optional[pulumi.Input[builtins.str]] = None,
            retention_period_duration: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            snapshot_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            writes_to_commit_log_enabled: Optional[pulumi.Input[builtins.bool]] = None) -> 'M3DbNamespace':
        """
        Get an existing M3DbNamespace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] name: Name of the namespace. A namespace named "default" is mapped with already created default namespace instead of creating a new namespace.
        :param pulumi.Input[builtins.str] resolution: Resolution for an aggregated namespace. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_block_data_expiration_duration: Controls how long we wait before expiring stale data. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_block_size_duration: Controls how long to keep a block in memory before flushing to a fileset on disk. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_buffer_future_duration: Controls how far into the future writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_buffer_past_duration: Controls how far into the past writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] retention_period_duration: Controls the duration of time that M3DB will retain data for the namespace. Should follow Rfc3339 e.g P2D, PT48H.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.bool] snapshot_enabled: Defines whether M3DB will create snapshot files for this namespace.
        :param pulumi.Input[builtins.str] type: Type of namespace.
        :param pulumi.Input[builtins.bool] writes_to_commit_log_enabled: Defines whether M3DB will include writes to this namespace in the commit log.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _M3DbNamespaceState.__new__(_M3DbNamespaceState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["name"] = name
        __props__.__dict__["resolution"] = resolution
        __props__.__dict__["retention_block_data_expiration_duration"] = retention_block_data_expiration_duration
        __props__.__dict__["retention_block_size_duration"] = retention_block_size_duration
        __props__.__dict__["retention_buffer_future_duration"] = retention_buffer_future_duration
        __props__.__dict__["retention_buffer_past_duration"] = retention_buffer_past_duration
        __props__.__dict__["retention_period_duration"] = retention_period_duration
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["snapshot_enabled"] = snapshot_enabled
        __props__.__dict__["type"] = type
        __props__.__dict__["writes_to_commit_log_enabled"] = writes_to_commit_log_enabled
        return M3DbNamespace(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the namespace. A namespace named "default" is mapped with already created default namespace instead of creating a new namespace.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def resolution(self) -> pulumi.Output[builtins.str]:
        """
        Resolution for an aggregated namespace. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "resolution")

    @property
    @pulumi.getter(name="retentionBlockDataExpirationDuration")
    def retention_block_data_expiration_duration(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Controls how long we wait before expiring stale data. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_block_data_expiration_duration")

    @property
    @pulumi.getter(name="retentionBlockSizeDuration")
    def retention_block_size_duration(self) -> pulumi.Output[builtins.str]:
        """
        Controls how long to keep a block in memory before flushing to a fileset on disk. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_block_size_duration")

    @property
    @pulumi.getter(name="retentionBufferFutureDuration")
    def retention_buffer_future_duration(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Controls how far into the future writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_buffer_future_duration")

    @property
    @pulumi.getter(name="retentionBufferPastDuration")
    def retention_buffer_past_duration(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Controls how far into the past writes to the namespace will be accepted. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_buffer_past_duration")

    @property
    @pulumi.getter(name="retentionPeriodDuration")
    def retention_period_duration(self) -> pulumi.Output[builtins.str]:
        """
        Controls the duration of time that M3DB will retain data for the namespace. Should follow Rfc3339 e.g P2D, PT48H.
        """
        return pulumi.get(self, "retention_period_duration")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="snapshotEnabled")
    def snapshot_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Defines whether M3DB will create snapshot files for this namespace.
        """
        return pulumi.get(self, "snapshot_enabled")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        Type of namespace.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="writesToCommitLogEnabled")
    def writes_to_commit_log_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        Defines whether M3DB will include writes to this namespace in the commit log.
        """
        return pulumi.get(self, "writes_to_commit_log_enabled")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetFailoverIpAttachResult',
    'AwaitableGetFailoverIpAttachResult',
    'get_failover_ip_attach',
    'get_failover_ip_attach_output',
]

@pulumi.output_type
class GetFailoverIpAttachResult:
    """
    A collection of values returned by getFailoverIpAttach.
    """
    def __init__(__self__, block=None, continent_code=None, geo_loc=None, id=None, ip=None, progress=None, routed_to=None, service_name=None, status=None, sub_type=None):
        if block and not isinstance(block, str):
            raise TypeError("Expected argument 'block' to be a str")
        pulumi.set(__self__, "block", block)
        if continent_code and not isinstance(continent_code, str):
            raise TypeError("Expected argument 'continent_code' to be a str")
        pulumi.set(__self__, "continent_code", continent_code)
        if geo_loc and not isinstance(geo_loc, str):
            raise TypeError("Expected argument 'geo_loc' to be a str")
        pulumi.set(__self__, "geo_loc", geo_loc)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip and not isinstance(ip, str):
            raise TypeError("Expected argument 'ip' to be a str")
        pulumi.set(__self__, "ip", ip)
        if progress and not isinstance(progress, int):
            raise TypeError("Expected argument 'progress' to be a int")
        pulumi.set(__self__, "progress", progress)
        if routed_to and not isinstance(routed_to, str):
            raise TypeError("Expected argument 'routed_to' to be a str")
        pulumi.set(__self__, "routed_to", routed_to)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if sub_type and not isinstance(sub_type, str):
            raise TypeError("Expected argument 'sub_type' to be a str")
        pulumi.set(__self__, "sub_type", sub_type)

    @property
    @pulumi.getter
    def block(self) -> builtins.str:
        """
        The IP block
        * `continentCode` - The Ip continent
        """
        return pulumi.get(self, "block")

    @property
    @pulumi.getter(name="continentCode")
    def continent_code(self) -> builtins.str:
        return pulumi.get(self, "continent_code")

    @property
    @pulumi.getter(name="geoLoc")
    def geo_loc(self) -> builtins.str:
        return pulumi.get(self, "geo_loc")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The Ip id
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ip(self) -> builtins.str:
        """
        The Ip Address
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter
    def progress(self) -> builtins.int:
        """
        Current operation progress in percent
        * `routedTo` - Instance where ip is routed to
        """
        return pulumi.get(self, "progress")

    @property
    @pulumi.getter(name="routedTo")
    def routed_to(self) -> builtins.str:
        return pulumi.get(self, "routed_to")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Ip status, can be `ok` or `operationPending`
        * `subType` - IP sub type, can be `cloud` or `ovh`
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subType")
    def sub_type(self) -> builtins.str:
        return pulumi.get(self, "sub_type")


class AwaitableGetFailoverIpAttachResult(GetFailoverIpAttachResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFailoverIpAttachResult(
            block=self.block,
            continent_code=self.continent_code,
            geo_loc=self.geo_loc,
            id=self.id,
            ip=self.ip,
            progress=self.progress,
            routed_to=self.routed_to,
            service_name=self.service_name,
            status=self.status,
            sub_type=self.sub_type)


def get_failover_ip_attach(block: Optional[builtins.str] = None,
                           continent_code: Optional[builtins.str] = None,
                           geo_loc: Optional[builtins.str] = None,
                           ip: Optional[builtins.str] = None,
                           routed_to: Optional[builtins.str] = None,
                           service_name: Optional[builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFailoverIpAttachResult:
    """
    Use this data source to get the details of a failover IP address of a service in a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_failover_ip = ovh.CloudProject.get_failover_ip_attach(service_name="XXXXXX",
        ip="XXXXXX")
    ```


    :param builtins.str block: The IP block
           * `continentCode` - The Ip continent
    :param builtins.str ip: The failover ip address to query
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['block'] = block
    __args__['continentCode'] = continent_code
    __args__['geoLoc'] = geo_loc
    __args__['ip'] = ip
    __args__['routedTo'] = routed_to
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getFailoverIpAttach:getFailoverIpAttach', __args__, opts=opts, typ=GetFailoverIpAttachResult).value

    return AwaitableGetFailoverIpAttachResult(
        block=pulumi.get(__ret__, 'block'),
        continent_code=pulumi.get(__ret__, 'continent_code'),
        geo_loc=pulumi.get(__ret__, 'geo_loc'),
        id=pulumi.get(__ret__, 'id'),
        ip=pulumi.get(__ret__, 'ip'),
        progress=pulumi.get(__ret__, 'progress'),
        routed_to=pulumi.get(__ret__, 'routed_to'),
        service_name=pulumi.get(__ret__, 'service_name'),
        status=pulumi.get(__ret__, 'status'),
        sub_type=pulumi.get(__ret__, 'sub_type'))
def get_failover_ip_attach_output(block: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                  continent_code: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                  geo_loc: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                  ip: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                  routed_to: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                  service_name: Optional[pulumi.Input[builtins.str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFailoverIpAttachResult]:
    """
    Use this data source to get the details of a failover IP address of a service in a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_failover_ip = ovh.CloudProject.get_failover_ip_attach(service_name="XXXXXX",
        ip="XXXXXX")
    ```


    :param builtins.str block: The IP block
           * `continentCode` - The Ip continent
    :param builtins.str ip: The failover ip address to query
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['block'] = block
    __args__['continentCode'] = continent_code
    __args__['geoLoc'] = geo_loc
    __args__['ip'] = ip
    __args__['routedTo'] = routed_to
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getFailoverIpAttach:getFailoverIpAttach', __args__, opts=opts, typ=GetFailoverIpAttachResult)
    return __ret__.apply(lambda __response__: GetFailoverIpAttachResult(
        block=pulumi.get(__response__, 'block'),
        continent_code=pulumi.get(__response__, 'continent_code'),
        geo_loc=pulumi.get(__response__, 'geo_loc'),
        id=pulumi.get(__response__, 'id'),
        ip=pulumi.get(__response__, 'ip'),
        progress=pulumi.get(__response__, 'progress'),
        routed_to=pulumi.get(__response__, 'routed_to'),
        service_name=pulumi.get(__response__, 'service_name'),
        status=pulumi.get(__response__, 'status'),
        sub_type=pulumi.get(__response__, 'sub_type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ServerRebootTaskArgs', 'ServerRebootTask']

@pulumi.input_type
class ServerRebootTaskArgs:
    def __init__(__self__, *,
                 keepers: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 service_name: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a ServerRebootTask resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] keepers: List of values tracked to trigger reboot, used also to form implicit dependencies.
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server.
        """
        pulumi.set(__self__, "keepers", keepers)
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def keepers(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        List of values tracked to trigger reboot, used also to form implicit dependencies.
        """
        return pulumi.get(self, "keepers")

    @keepers.setter
    def keepers(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "keepers", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The service_name of your dedicated server.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _ServerRebootTaskState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[builtins.str]] = None,
                 done_date: Optional[pulumi.Input[builtins.str]] = None,
                 function: Optional[pulumi.Input[builtins.str]] = None,
                 keepers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 last_update: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 start_date: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServerRebootTask resources.
        :param pulumi.Input[builtins.str] comment: Details of this task. (should be `Reboot asked`)
        :param pulumi.Input[builtins.str] done_date: Completion date in RFC3339 format.
        :param pulumi.Input[builtins.str] function: Function name (should be `hardReboot`).
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] keepers: List of values tracked to trigger reboot, used also to form implicit dependencies.
        :param pulumi.Input[builtins.str] last_update: Last update in RFC3339 format.
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server.
        :param pulumi.Input[builtins.str] start_date: Task creation date in RFC3339 format.
        :param pulumi.Input[builtins.str] status: Task status (should be `done`)
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if done_date is not None:
            pulumi.set(__self__, "done_date", done_date)
        if function is not None:
            pulumi.set(__self__, "function", function)
        if keepers is not None:
            pulumi.set(__self__, "keepers", keepers)
        if last_update is not None:
            pulumi.set(__self__, "last_update", last_update)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if start_date is not None:
            pulumi.set(__self__, "start_date", start_date)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Details of this task. (should be `Reboot asked`)
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="doneDate")
    def done_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Completion date in RFC3339 format.
        """
        return pulumi.get(self, "done_date")

    @done_date.setter
    def done_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "done_date", value)

    @property
    @pulumi.getter
    def function(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Function name (should be `hardReboot`).
        """
        return pulumi.get(self, "function")

    @function.setter
    def function(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "function", value)

    @property
    @pulumi.getter
    def keepers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of values tracked to trigger reboot, used also to form implicit dependencies.
        """
        return pulumi.get(self, "keepers")

    @keepers.setter
    def keepers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "keepers", value)

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Last update in RFC3339 format.
        """
        return pulumi.get(self, "last_update")

    @last_update.setter
    def last_update(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "last_update", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service_name of your dedicated server.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task creation date in RFC3339 format.
        """
        return pulumi.get(self, "start_date")

    @start_date.setter
    def start_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start_date", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Task status (should be `done`)
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("ovh:Dedicated/serverRebootTask:ServerRebootTask")
class ServerRebootTask(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 keepers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        rescue = ovh.Dedicated.get_server_boots(service_name="nsxxxxxxx.ip-xx-xx-xx.eu",
            boot_type="rescue",
            kernel="rescue64-pro")
        server_on_rescue = ovh.dedicated.ServerUpdate("server_on_rescue",
            service_name="nsxxxxxxx.ip-xx-xx-xx.eu",
            boot_id=rescue.results[0],
            monitoring=True,
            state="ok")
        server_reboot = ovh.dedicated.ServerRebootTask("server_reboot",
            service_name=rescue.service_name,
            keepers=[server_on_rescue.boot_id])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] keepers: List of values tracked to trigger reboot, used also to form implicit dependencies.
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServerRebootTaskArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        rescue = ovh.Dedicated.get_server_boots(service_name="nsxxxxxxx.ip-xx-xx-xx.eu",
            boot_type="rescue",
            kernel="rescue64-pro")
        server_on_rescue = ovh.dedicated.ServerUpdate("server_on_rescue",
            service_name="nsxxxxxxx.ip-xx-xx-xx.eu",
            boot_id=rescue.results[0],
            monitoring=True,
            state="ok")
        server_reboot = ovh.dedicated.ServerRebootTask("server_reboot",
            service_name=rescue.service_name,
            keepers=[server_on_rescue.boot_id])
        ```

        :param str resource_name: The name of the resource.
        :param ServerRebootTaskArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServerRebootTaskArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 keepers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServerRebootTaskArgs.__new__(ServerRebootTaskArgs)

            if keepers is None and not opts.urn:
                raise TypeError("Missing required property 'keepers'")
            __props__.__dict__["keepers"] = keepers
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["comment"] = None
            __props__.__dict__["done_date"] = None
            __props__.__dict__["function"] = None
            __props__.__dict__["last_update"] = None
            __props__.__dict__["start_date"] = None
            __props__.__dict__["status"] = None
        super(ServerRebootTask, __self__).__init__(
            'ovh:Dedicated/serverRebootTask:ServerRebootTask',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[builtins.str]] = None,
            done_date: Optional[pulumi.Input[builtins.str]] = None,
            function: Optional[pulumi.Input[builtins.str]] = None,
            keepers: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            last_update: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            start_date: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'ServerRebootTask':
        """
        Get an existing ServerRebootTask resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] comment: Details of this task. (should be `Reboot asked`)
        :param pulumi.Input[builtins.str] done_date: Completion date in RFC3339 format.
        :param pulumi.Input[builtins.str] function: Function name (should be `hardReboot`).
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] keepers: List of values tracked to trigger reboot, used also to form implicit dependencies.
        :param pulumi.Input[builtins.str] last_update: Last update in RFC3339 format.
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server.
        :param pulumi.Input[builtins.str] start_date: Task creation date in RFC3339 format.
        :param pulumi.Input[builtins.str] status: Task status (should be `done`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServerRebootTaskState.__new__(_ServerRebootTaskState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["done_date"] = done_date
        __props__.__dict__["function"] = function
        __props__.__dict__["keepers"] = keepers
        __props__.__dict__["last_update"] = last_update
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["start_date"] = start_date
        __props__.__dict__["status"] = status
        return ServerRebootTask(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[builtins.str]:
        """
        Details of this task. (should be `Reboot asked`)
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="doneDate")
    def done_date(self) -> pulumi.Output[builtins.str]:
        """
        Completion date in RFC3339 format.
        """
        return pulumi.get(self, "done_date")

    @property
    @pulumi.getter
    def function(self) -> pulumi.Output[builtins.str]:
        """
        Function name (should be `hardReboot`).
        """
        return pulumi.get(self, "function")

    @property
    @pulumi.getter
    def keepers(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        List of values tracked to trigger reboot, used also to form implicit dependencies.
        """
        return pulumi.get(self, "keepers")

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> pulumi.Output[builtins.str]:
        """
        Last update in RFC3339 format.
        """
        return pulumi.get(self, "last_update")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The service_name of your dedicated server.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="startDate")
    def start_date(self) -> pulumi.Output[builtins.str]:
        """
        Task creation date in RFC3339 format.
        """
        return pulumi.get(self, "start_date")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Task status (should be `done`)
        """
        return pulumi.get(self, "status")

